#ifdef BSD
#ifndef BSD4_1
#define HAVE_GETPAGESIZE
#endif
#endif

#ifndef HAVE_GETPAGESIZE

#ifdef USG5_4

#include <unistd.h>
#define getpagesize()	sysconf(_SC_PAGESIZE)

#else	/* USG5_4 */

#ifdef VMS
#include "param.h"
#else
#include <sys/param.h>
#endif

#ifdef EXEC_PAGESIZE
#define getpagesize() EXEC_PAGESIZE
#else
#ifdef NBPG
#define getpagesize() NBPG * CLSIZE
#ifndef CLSIZE
#define CLSIZE 1
#endif /* no CLSIZE */
#else /* no NBPG */
#define getpagesize() NBPC
#endif /* no NBPG */
#endif /* no EXEC_PAGESIZE */

#endif /* USG5_4 */

#endif /* not HAVE_GETPAGESIZE */

